==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/modeldatatoresourcedatainterfile/rev20160826/modeldatatoresourcedatainterfile/firstlevel/containerchoice/choicecase/augmentedschchoicecase/DefaultLeafInterAug.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.modeldatatoresourcedatainterfile.rev20160826.modeldatatoresourcedatainterfile.firstlevel.containerchoice.choicecase.augmentedschchoicecase;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.modeldatatoresourcedata.rev20160826.modeldatatoresourcedata.Uri;
import org.onosproject.yang.gen.v1.modeldatatoresourcedata.rev20160826.modeldatatoresourcedata.firstlevel.containerchoice.ChoiceCase;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of leafInterAug.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultLeafInterAug extends InnerModelObject implements LeafInterAug {
    protected Uri leafInterAug;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public Uri leafInterAug() {
        return leafInterAug;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void leafInterAug(Uri leafInterAug) {
        valueLeafFlags.set(LeafIdentifier.LEAFINTERAUG.getLeafIndex());
        this.leafInterAug = leafInterAug;
    }

    @Override
    public int hashCode() {
        return Objects.hash(leafInterAug, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultLeafInterAug) {
            DefaultLeafInterAug other = (DefaultLeafInterAug) obj;
            return
                Objects.equals(leafInterAug, other.leafInterAug) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("leafInterAug=" + leafInterAug)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultLeafInterAug.
     */
    public DefaultLeafInterAug() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/modeldatatoresourcedatainterfile/rev20160826/modeldatatoresourcedatainterfile/firstlevel/containerchoice/choicecase/augmentedschchoicecase/DefaultLeafInterAug.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.modeldatatoresourcedatainterfile.rev20160826.modeldatatoresourcedatainterfile.firstlevel.containerchoice.choicecase.augmentedschchoicecase;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.modeldatatoresourcedata.rev20160826.modeldatatoresourcedata.Uri;
import org.onosproject.yang.gen.v1.modeldatatoresourcedata.rev20160826.modeldatatoresourcedata.firstlevel.containerchoice.ChoiceCase;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of leafInterAug.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultLeafInterAug extends InnerModelObject implements LeafInterAug {
    protected Uri leafInterAug;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public Uri leafInterAug() {
        return leafInterAug;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void leafInterAug(Uri leafInterAug) {
        valueLeafFlags.set(LeafIdentifier.LEAFINTERAUG.getLeafIndex());
        this.leafInterAug = leafInterAug;
    }

    @Override
    public int hashCode() {
        return Objects.hash(leafInterAug, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultLeafInterAug) {
            DefaultLeafInterAug other = (DefaultLeafInterAug) obj;
            return
                Objects.deepEquals(leafInterAug, other.leafInterAug) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("leafInterAug=" + leafInterAug)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultLeafInterAug.
     */
    public DefaultLeafInterAug() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
